#!/usr/bin/env python3

## SPDX-FileCopyrightText: 2025 Benjamin Grande M. S. <ben.grande.b@gmail.com>
## SPDX-FileCopyrightText: 2025 ENCRYPTED SUPPORT LLC <adrelanos@whonix.org>
##
## SPDX-License-Identifier: AGPL-3.0-or-later

"""Safely print stdin or file to stdout."""

from fileinput import input as file_input
from sys import stdin, stdout, modules
from stdisplay.stdisplay import stdisplay


def main() -> None:
    """Safely print stdin or file to stdout."""
    # https://github.com/pytest-dev/pytest/issues/4843
    if "pytest" not in modules:
        stdin.reconfigure(errors="ignore")  # type: ignore
    ## File input reads stdin when no file is provided or file is '-'.
    for untrusted_text in file_input(encoding="ascii", errors="replace"):
        stdout.write(stdisplay(untrusted_text))
    stdout.flush()


if __name__ == "__main__":
    main()
